How to use ?
into the dir: nameko-mongo and run "python setup.py build" to build the lib, then run "python setup.py install";
if you want use it in Docker, please do the same steps in your docker contianers.
